#!/bin/bash

# This file installs the extra fonts locally for the running user.
# This file must be located in tomenet/lib/xtra folder!


# path of local font folder, which we will create if it doesn't exist yet
LOCALFONTPATH=~/.local/share/fonts/misc

# paths to system's font config
FONTCFG=/etc/fonts/conf.d
FONTCFGAVAIL=/usr/share/fontconfig/conf.avail

# location of TomeNET's user folder, from our working directory
TOMENETUSER=../user


# Check for correct surroundings

if [ ! -d _extra_fonts ]; then
    echo ""
    echo "  Error: Font folder '_extra_fonts' not found in current directory."
    echo "  This script must be located and called in TomeNET's ./lib/xtra/ folder!"
    echo ""
    exit 1
fi
if [ ! -d $TOMENETUSER ]; then
    echo ""
    echo "  Error: TomeNET's lib/xtra folder structure not found."
    echo "  This script must be located and called in TomeNET's ./lib/xtra/ folder!"
    echo ""
    exit 1
fi

echo ""
echo "  Installing extra fonts!"
echo ""


# Ubuntu has this silly no-bitmap-fonts config

if [ -f $FONTCFG/70-no-bitmaps.conf ]; then
    echo "  Found bitmap-preventing setting: $FONTCFG/70-no-bitmaps.conf"
    echo "   Trying to delete this file, in order to enable bitmap font usage:"
    sudo rm -v $FONTCFG/70-no-bitmaps.conf
else
    echo "  Confirmed absense of $FONTCFG/70-no-bitmap.conf - good!"
fi
if [ ! -f $FONTCFG/70-yes-bitmaps.conf ]; then
    echo "  Trying to instantiate: $FONTCFG/70-yes-bitmaps.conf"
    echo "   As it is needed on some systems, in order to enable bitmap font usage:"
    sudo ln -v -s $FONTCFGAVAIL/70-yes-bitmaps.conf $FONTCFG/
else
    echo "  Confirmed presense of $FONTCFG/70-yes-bitmap.conf - good!"
fi
echo ""


# Tangar's fonts:

FONTDIR=tangar

echo "   Installing $FONTDIR fonts:"
mkdir -p $LOCALFONTPATH

echo "    copying .prf files..."
cp _extra_fonts/$FONTDIR/prf/*.prf $TOMENETUSER/

echo "    copying .pcf files..."
cp _extra_fonts/$FONTDIR/pcf/*.pcf $LOCALFONTPATH/

echo "    building local fonts folder at '$LOCALFONTPATH'..."
mkfontdir $LOCALFONTPATH

echo "    adding that folder to fonts path ('xset q' to check)..."
xset +fp $LOCALFONTPATH

echo "    registering fonts in the system..."
fc-cache -f

echo "    These fonts are now recognized by the system:"
ls -1  _extra_fonts/$FONTDIR/pcf/*.pcf | grep -o "[^/][0-9a-z]*.pcf$" | grep -o "^[^.]*" > _extra_fonts_list.tmp
xlsfonts |grep -f _extra_fonts_list.tmp | tr '\n' ' '
rm _extra_fonts_list.tmp
echo ""


# Finished
echo ""
